@@ -8,8 +8,7 @@ from core_main_app.utils.integration_tests.fixture_interface import FixtureInter
 
 
 class DataRegistryFixtures(FixtureInterface):
-    """ Data fixtures
-    """
+    """Data fixtures"""
 
     data_1 = None
     data_2 = None
@@ -17,7 +16,7 @@ class DataRegistryFixtures(FixtureInterface):
     data_collection = None
 
     def insert_data(self):
-        """ Insert a set of Data.
+        """Insert a set of Data.
 
         Returns:
 
@@ -27,7 +26,7 @@ class DataRegistryFixtures(FixtureInterface):
         self.generate_data_collection()
 
     def generate_data_collection(self):
-        """ Generate a Data collection.
+        """Generate a Data collection.
 
         Returns:
 
@@ -46,7 +45,7 @@ class DataRegistryFixtures(FixtureInterface):
         self.data_collection = [self.data_1, self.data_2]
 
     def generate_template(self):
-        """ Generate an unique Template.
+        """Generate an unique Template.
 
         Returns:
 
